<?php 

/*
 * AfterLogic WebMail Pro PHP by AfterLogic Corp. <support@afterlogic.com>
 *
 * Copyright (C) 2002-2009  AfterLogic Corp. (www.afterlogic.com)
 * Distributed under the terms of the proprietary AfterLogic Computer License (LICENSE.txt)
 * 
 */

@ob_start('writeJsonResponse');
$TimeZones = array();

if (!defined('WM_ROOTPATH')) define('WM_ROOTPATH', (dirname(__FILE__).'/../'));

require_once(WM_ROOTPATH.'class_settings.php');
require_once(WM_ROOTPATH.'calendar/class_settings.php');
include_once(WM_ROOTPATH.'calendar/db_query.php');
require_once(WM_ROOTPATH.'calendar/lib.php');
/*require_once(WM_ROOTPATH.'calendar/class_calendar_account.php');*/
require_once(WM_ROOTPATH.'common/timezones.php');
require_once(WM_ROOTPATH.'common/class_log.php');

$log =& CLog::CreateInstance();

/**
 * @param string $response
 * @return string
 */
function writeJsonResponse($response)
{
	global $log;
	$log->WriteLine('<<< calendar JSON:'."\r\n".$response);
	return $response;
}

$wm_settings = &Settings::CreateInstance();
if (!$wm_settings || !$wm_settings->isLoad || !$wm_settings->IncludeLang()) 
{
	$log->WriteLine('calendar error: Can\'t get settings or language file.');
	exit(getErrorJson(0, ErrorGeneral));
}

$settings = new CalSettings($wm_settings);

SQL::init($settings->DbHost, $settings->DbLogin, $settings->DbPassword, $settings->DbName);

$action = isset($_GET['action']) ? $_GET['action'] : (isset($_POST['action'])? $_POST['action'] : '');

@session_name('PHPWEBMAILSESSID');
@session_start(); 


$log =& CLog::CreateInstance();
$log->WriteLine('>>> calendar GET:'."\r\n".dumpGet());
$calendar_id = 0;
$calendarArray = array();


if(isset($_SESSION[CALENDAR_ID], $_SESSION[ACCESS_LEVEL])) 
{
	$calendar_id = (int) $_SESSION[CALENDAR_ID];
	$tz = isset($settings->DefaultTimeZone, $TimeZones[$settings->DefaultTimeZone][0]) ? $TimeZones[$settings->DefaultTimeZone][0] : null;
	$tzs = ($tz) ? explode(':', $tz) : null;
	if ($tzs && count($tzs) > 1)
	{ 
		$tzone = 60*(intval($tzs[1]) + 60*intval($tzs[0]));
	}
}
else
{
	$log->WriteLine('calendar error: '.PROC_SESSION_ERROR);
	exit(getErrorJson(0, PROC_SESSION_ERROR));
}


switch ($action)
{
	case 'get_events':
		if (isset($_GET['from'], $_GET['till']))
		{
			$response = array();
			$from = (int) $_GET['from'];
			$till = (int) $_GET['till'];
			
			if ($till >= $from)
			{
				$eventeArray = SQL::SelectCalendarEvents($settings->DbPrefix, todt($from, false, -$tzone), todt($till, true, -$tzone), $calendar_id);
				foreach ($eventeArray as $event) 
				{
					$event_id = intval($event['event_id']); 
					$response[$event_id] = $event;  
					$response[$event_id]['event_timefrom'] = addsql($event['event_timefrom'], $tzone);
					$response[$event_id]['event_timetill'] = addsql($event['event_timetill'], $tzone);
				}
			}
			echo json_encode($response);
		}
		else
		{
			echo json_encode(array()); 
		}
		break;

	case 'get_year_events':

		if (isset($_GET["date"]))
		{
			$result = SQL::SelectCalendarYearEvents($settings->DbPrefix, (int) $_GET['date'], $calendar_id);
			$response = array();
			foreach ($result as $value) 
			{
				$from_timestamp = fromsql($value['event_timefrom']) + $tzone;
				$till_timestamp = fromsql($value['event_timetill']) + $tzone;
				$add_value_timefrom = date('Ymd', $from_timestamp);
				$add_value_timetill = date('Ymd', $till_timestamp);
			
				if ($add_value_timefrom == $add_value_timetill) 
				{ 
					if (!in_array($add_value_timetill, $response))
					{
						array_push($response, $add_value_timetill);
					}
				} 
				else
				{
					$days = floor(($till_timestamp - $from_timestamp)/86400);
					for ($i = 0; $i <= $days; $i++) 
					{
						$add_date = date('Ymd', ($from_timestamp + 86400*$i));
						if (!in_array($add_date, $response)) 
						{
							array_push($response, $add_date);
						}
					}
				}
			}
			echo json_encode($response);
		}
		else
		{
			echo json_encode(array()); 
		}
		break;

	case 'get_calendar':
		if (isset($calendar_id)) {
			$calendarArray = SQL::SelectPublicCalendar($settings->DbPrefix, $calendar_id);
			if ($calendarArray && count($calendarArray) > 0)
			{
				foreach ($calendarArray as $value)
				{
					$calendar_id = intval($value['calendar_id']); 

					$keyArray = array('calendar_id', 'calendar_name', 'calendar_description', 'calendar_color', 'calendar_active', 'publication_level');
					$valArray = array();

					foreach ($value as $key => $val) 
					{
						if (in_array($key, $keyArray))
						{
							$valArray[$key] = $val;
						}
					}
				}
				echo json_encode($valArray);
			} else {
				$log->WriteLine('calendar error: Unable to load calendar');
				echo getErrorJson(0, 'Unable to load calendar');
			}
		} else {
			$log->WriteLine('calendar error: Unable to load calendar');
			echo getErrorJson(0, 'Unable to load calendar');
		}
		break;

	default:
		
		$log->WriteLine('calendar error: NULL JSON');
		echo getErrorJson(0, ErrorGeneral);
		break;
}

/**
 * @param int $data
 * @param int $min
 * @param int $max
 * @return bool
 */
function controlData($data, $min, $max)
{
	$data = round($data);
	
	return (isset($min) && isset($max))
				? ($min <= $data && $data <= $max)
				: ($data > 0);
}

/**
 * @param string $country
 * @return bool
 */
function controlCountry($country)
{
	if (!$country) 
	{
		return false;
	}
	if (file_exists(INI_DIR.'/country/country.dat'))
	{
		$fp = @fopen(INI_DIR.'/country/country.dat','r');
		if ($fp)
		{
			while (!feof($fp))
			{
				$str = trim(fgets($fp));
				list($CCode) = split ('-', $str);
				if ($country == $CCode){
					@fclose($fp);
					return true;
				}
			}
			@fclose($fp); 
			return false;
		}
		else
		{
			$log =& CLog::CreateInstance();
			$log->WriteLine('Can\'t read '.INI_DIR.'/country/country.dat file.');
		}
	}
	else
	{
		$log =& CLog::CreateInstance();
		$log->WriteLine('Can\'t read '.INI_DIR.'/country/country.dat file.');
	}
	return false;
}

/**
 * @param string $action
 * @param int $code
 * @param string $reason
 * @return string
 */
function getErrorJson($code, $description)
{
	$array = array(
		'error' => 'true',
		'code' => $code,
		'description' => $description
	);
	return json_encode($array);
}

/**
 * @param string $prefix
 * @param int $user_id
 * @param int $calendar_id
 * @return bool
 */
function checkCalendarId($prefix, $user_id, $calendar_id)
{
	if ($calendar_id === 0) 
	{
		return true;
	}
	
	return SQL::CheckCalendarsByUserId($prefix, $calendar_id, $user_id);
}
